@@ -11,4 +11,7 @@ from dataclasses import dataclass
 
 @dataclass
 class ObstructionSettings:
-    to_be_done: str = "to_be_done"
+    rtsp_url: str
+    similarity_threshold: float
+    created_at: float | None = None
+    updated_at: float | None = None
